==> ruby-vtk_0.1.1.orig.tar.gz: ruby-vtk-0.1.1.orig/Filtering/Filtering.cxx <==
#if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#  if !defined(STATIC_LINKED)
#    define SWIGEXPORT(a) __declspec(dllexport) a
#  else
#    define SWIGEXPORT(a) a
#  endif
#else
#  define SWIGEXPORT(a) a
#endif


#ifdef __cplusplus
extern "C" {
#endif
extern SWIGEXPORT(void) Init_vtkFilteringInstantiator(void);
extern SWIGEXPORT(void) Init_vtkCellLocator(void);
extern SWIGEXPORT(void) Init_vtkColorTransferFunction(void);
extern SWIGEXPORT(void) Init_vtkCone(void);
extern SWIGEXPORT(void) Init_vtkCylinder(void);
extern SWIGEXPORT(void) Init_vtkDataObjectSource(void);
extern SWIGEXPORT(void) Init_vtkDataSetSource(void);
extern SWIGEXPORT(void) Init_vtkDataSetToDataSetFilter(void);
extern SWIGEXPORT(void) Init_vtkImageSource(void);
extern SWIGEXPORT(void) Init_vtkImageToImageFilter(void);
extern SWIGEXPORT(void) Init_vtkImageToStructuredPoints(void);
extern SWIGEXPORT(void) Init_vtkImplicitBoolean(void);
extern SWIGEXPORT(void) Init_vtkImplicitDataSet(void);
extern SWIGEXPORT(void) Init_vtkImplicitSelectionLoop(void);
extern SWIGEXPORT(void) Init_vtkImplicitSum(void);
extern SWIGEXPORT(void) Init_vtkImplicitVolume(void);
extern SWIGEXPORT(void) Init_vtkImplicitWindowFunction(void);
extern SWIGEXPORT(void) Init_vtkMergePoints(void);
extern SWIGEXPORT(void) Init_vtkPerlinNoise(void);
extern SWIGEXPORT(void) Init_vtkPiecewiseFunction(void);
extern SWIGEXPORT(void) Init_vtkPiecewiseFunctionSource(void);
extern SWIGEXPORT(void) Init_vtkPiecewiseFunctionToPiecewiseFunctionFilter(void);
extern SWIGEXPORT(void) Init_vtkPointSetSource(void);
extern SWIGEXPORT(void) Init_vtkPointSetToPointSetFilter(void);
extern SWIGEXPORT(void) Init_vtkPolyDataCollection(void);
extern SWIGEXPORT(void) Init_vtkPolyDataSource(void);
extern SWIGEXPORT(void) Init_vtkPolyDataToPolyDataFilter(void);
extern SWIGEXPORT(void) Init_vtkRectilinearGridSource(void);
extern SWIGEXPORT(void) Init_vtkRectilinearGridToPolyDataFilter(void);
extern SWIGEXPORT(void) Init_vtkScalarTree(void);
extern SWIGEXPORT(void) Init_vtkSimpleImageToImageFilter(void);
extern SWIGEXPORT(void) Init_vtkSimpleScalarTree(void);
extern SWIGEXPORT(void) Init_vtkSphere(void);
extern SWIGEXPORT(void) Init_vtkSpline(void);
extern SWIGEXPORT(void) Init_vtkStructuredGridSource(void);
extern SWIGEXPORT(void) Init_vtkStructuredGridToPolyDataFilter(void);
extern SWIGEXPORT(void) Init_vtkStructuredGridToStructuredGridFilter(void);
extern SWIGEXPORT(void) Init_vtkStructuredPointsCollection(void);
extern SWIGEXPORT(void) Init_vtkStructuredPointsSource(void);
extern SWIGEXPORT(void) Init_vtkStructuredPointsToPolyDataFilter(void);
extern SWIGEXPORT(void) Init_vtkStructuredPointsToStructuredPointsFilter(void);
extern SWIGEXPORT(void) Init_vtkSuperquadric(void);
extern SWIGEXPORT(void) Init_vtkUnstructuredGridSource(void);
extern SWIGEXPORT(void) Init_vtkUnstructuredGridToPolyDataFilter(void);
extern SWIGEXPORT(void) Init_vtkUnstructuredGridToUnstructuredGridFilter(void);
extern SWIGEXPORT(void) Init_vtkCardinalSpline(void);
extern SWIGEXPORT(void) Init_vtkCastToConcrete(void);
extern SWIGEXPORT(void) Init_vtkDataSetToImageFilter(void);
extern SWIGEXPORT(void) Init_vtkDataSetToPolyDataFilter(void);
extern SWIGEXPORT(void) Init_vtkDataSetToStructuredGridFilter(void);
extern SWIGEXPORT(void) Init_vtkDataSetToStructuredPointsFilter(void);
extern SWIGEXPORT(void) Init_vtkDataSetToUnstructuredGridFilter(void);
extern SWIGEXPORT(void) Init_vtkImageInPlaceFilter(void);
extern SWIGEXPORT(void) Init_vtkImageMultipleInputFilter(void);
extern SWIGEXPORT(void) Init_vtkImageMultipleInputOutputFilter(void);
extern SWIGEXPORT(void) Init_vtkImageTwoInputFilter(void);
extern SWIGEXPORT(void) Init_vtkKochanekSpline(void);
extern SWIGEXPORT(void) Init_vtkPiecewiseFunctionShiftScale(void);
extern SWIGEXPORT(void) Init_vtkStructuredPointsToUnstructuredGridFilter(void);
#ifdef __cplusplus
}
#endif

#ifdef __cplusplus
extern "C"
#endif
SWIGEXPORT(void) Init_Filtering(void){

  Init_vtkFilteringInstantiator();
  Init_vtkCellLocator();
  Init_vtkColorTransferFunction();
  Init_vtkCone();
  Init_vtkCylinder();
  Init_vtkDataObjectSource();
  Init_vtkDataSetSource();
  Init_vtkDataSetToDataSetFilter();
  Init_vtkImageSource();
  Init_vtkImageToImageFilter();
  Init_vtkImageToStructuredPoints();
  Init_vtkImplicitBoolean();
  Init_vtkImplicitDataSet();
  Init_vtkImplicitSelectionLoop();
  Init_vtkImplicitSum();
  Init_vtkImplicitVolume();
  Init_vtkImplicitWindowFunction();
  Init_vtkMergePoints();
  Init_vtkPerlinNoise();
  Init_vtkPiecewiseFunction();
  Init_vtkPiecewiseFunctionSource();
  Init_vtkPiecewiseFunctionToPiecewiseFunctionFilter();
  Init_vtkPointSetSource();
  Init_vtkPointSetToPointSetFilter();
  Init_vtkPolyDataCollection();
  Init_vtkPolyDataSource();
  Init_vtkPolyDataToPolyDataFilter();
  Init_vtkRectilinearGridSource();
  Init_vtkRectilinearGridToPolyDataFilter();
  Init_vtkScalarTree();
  Init_vtkSimpleImageToImageFilter();
  Init_vtkSimpleScalarTree();
  Init_vtkSphere();
  Init_vtkSpline();
  Init_vtkStructuredGridSource();
  Init_vtkStructuredGridToPolyDataFilter();
  Init_vtkStructuredGridToStructuredGridFilter();
  Init_vtkStructuredPointsCollection();
  Init_vtkStructuredPointsSource();
  Init_vtkStructuredPointsToPolyDataFilter();
  Init_vtkStructuredPointsToStructuredPointsFilter();
  Init_vtkSuperquadric();
  Init_vtkUnstructuredGridSource();
  Init_vtkUnstructuredGridToPolyDataFilter();
  Init_vtkUnstructuredGridToUnstructuredGridFilter();
  Init_vtkCardinalSpline();
  Init_vtkCastToConcrete();
  Init_vtkDataSetToImageFilter();
  Init_vtkDataSetToPolyDataFilter();
  Init_vtkDataSetToStructuredGridFilter();
  Init_vtkDataSetToStructuredPointsFilter();
  Init_vtkDataSetToUnstructuredGridFilter();
  Init_vtkImageInPlaceFilter();
  Init_vtkImageMultipleInputFilter();
  Init_vtkImageMultipleInputOutputFilter();
  Init_vtkImageTwoInputFilter();
  Init_vtkKochanekSpline();
  Init_vtkPiecewiseFunctionShiftScale();
  Init_vtkStructuredPointsToUnstructuredGridFilter();
}

==> ruby-vtk_0.2.0.orig.tar.gz: ruby-vtk-0.2.0.orig/Filtering/Filtering.cxx <==
#if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#  if !defined(STATIC_LINKED)
#    define SWIGEXPORT(a) __declspec(dllexport) a
#  else
#    define SWIGEXPORT(a) a
#  endif
#else
#  define SWIGEXPORT(a) a
#endif


#ifdef __cplusplus
extern "C" {
#endif
extern SWIGEXPORT(void) Init_vtkFilteringInstantiator(void);
extern SWIGEXPORT(void) Init_vtkApplyFilterCommand(void);
extern SWIGEXPORT(void) Init_vtkCellLocator(void);
extern SWIGEXPORT(void) Init_vtkColorTransferFunction(void);
extern SWIGEXPORT(void) Init_vtkCone(void);
extern SWIGEXPORT(void) Init_vtkCylinder(void);
extern SWIGEXPORT(void) Init_vtkDataObjectSource(void);
extern SWIGEXPORT(void) Init_vtkDataSetSource(void);
extern SWIGEXPORT(void) Init_vtkDataSetToDataSetFilter(void);
extern SWIGEXPORT(void) Init_vtkHierarchicalBoxSource(void);
extern SWIGEXPORT(void) Init_vtkHierarchicalBoxToHierarchicalBoxFilter(void);
extern SWIGEXPORT(void) Init_vtkImageSource(void);
extern SWIGEXPORT(void) Init_vtkImageToImageFilter(void);
extern SWIGEXPORT(void) Init_vtkImageToStructuredPoints(void);
extern SWIGEXPORT(void) Init_vtkImplicitBoolean(void);
extern SWIGEXPORT(void) Init_vtkImplicitDataSet(void);
extern SWIGEXPORT(void) Init_vtkImplicitSelectionLoop(void);
extern SWIGEXPORT(void) Init_vtkImplicitSum(void);
extern SWIGEXPORT(void) Init_vtkImplicitVolume(void);
extern SWIGEXPORT(void) Init_vtkImplicitWindowFunction(void);
extern SWIGEXPORT(void) Init_vtkMergePoints(void);
extern SWIGEXPORT(void) Init_vtkMultiBlockApplyFilterCommand(void);
extern SWIGEXPORT(void) Init_vtkPerlinNoise(void);
extern SWIGEXPORT(void) Init_vtkPiecewiseFunction(void);
extern SWIGEXPORT(void) Init_vtkPiecewiseFunctionSource(void);
extern SWIGEXPORT(void) Init_vtkPiecewiseFunctionToPiecewiseFunctionFilter(void);
extern SWIGEXPORT(void) Init_vtkPointSetSource(void);
extern SWIGEXPORT(void) Init_vtkPointSetToPointSetFilter(void);
extern SWIGEXPORT(void) Init_vtkPolyDataCollection(void);
extern SWIGEXPORT(void) Init_vtkPolyDataSource(void);
extern SWIGEXPORT(void) Init_vtkPolyDataToPolyDataFilter(void);
extern SWIGEXPORT(void) Init_vtkRectilinearGridSource(void);
extern SWIGEXPORT(void) Init_vtkRectilinearGridToPolyDataFilter(void);
extern SWIGEXPORT(void) Init_vtkScalarTree(void);
extern SWIGEXPORT(void) Init_vtkSimpleImageToImageFilter(void);
extern SWIGEXPORT(void) Init_vtkSimpleScalarTree(void);
extern SWIGEXPORT(void) Init_vtkSphere(void);
extern SWIGEXPORT(void) Init_vtkSpline(void);
extern SWIGEXPORT(void) Init_vtkStructuredGridSource(void);
extern SWIGEXPORT(void) Init_vtkStructuredGridToPolyDataFilter(void);
extern SWIGEXPORT(void) Init_vtkStructuredGridToStructuredGridFilter(void);
extern SWIGEXPORT(void) Init_vtkStructuredPointsCollection(void);
extern SWIGEXPORT(void) Init_vtkStructuredPointsSource(void);
extern SWIGEXPORT(void) Init_vtkStructuredPointsToPolyDataFilter(void);
extern SWIGEXPORT(void) Init_vtkStructuredPointsToStructuredPointsFilter(void);
extern SWIGEXPORT(void) Init_vtkSuperquadric(void);
extern SWIGEXPORT(void) Init_vtkUnstructuredGridSource(void);
extern SWIGEXPORT(void) Init_vtkUnstructuredGridToPolyDataFilter(void);
extern SWIGEXPORT(void) Init_vtkUnstructuredGridToUnstructuredGridFilter(void);
extern SWIGEXPORT(void) Init_vtkCardinalSpline(void);
extern SWIGEXPORT(void) Init_vtkCastToConcrete(void);
extern SWIGEXPORT(void) Init_vtkDataSetToImageFilter(void);
extern SWIGEXPORT(void) Init_vtkDataSetToPolyDataFilter(void);
extern SWIGEXPORT(void) Init_vtkDataSetToStructuredGridFilter(void);
extern SWIGEXPORT(void) Init_vtkDataSetToStructuredPointsFilter(void);
extern SWIGEXPORT(void) Init_vtkDataSetToUnstructuredGridFilter(void);
extern SWIGEXPORT(void) Init_vtkHierarchicalBoxToPolyDataFilter(void);
extern SWIGEXPORT(void) Init_vtkImageInPlaceFilter(void);
extern SWIGEXPORT(void) Init_vtkImageMultipleInputFilter(void);
extern SWIGEXPORT(void) Init_vtkImageMultipleInputOutputFilter(void);
extern SWIGEXPORT(void) Init_vtkImageTwoInputFilter(void);
extern SWIGEXPORT(void) Init_vtkKochanekSpline(void);
extern SWIGEXPORT(void) Init_vtkPiecewiseFunctionShiftScale(void);
extern SWIGEXPORT(void) Init_vtkStructuredPointsToUnstructuredGridFilter(void);
#ifdef __cplusplus
}
#endif

#ifdef __cplusplus
extern "C"
#endif
SWIGEXPORT(void) Init_Filtering(void){

  Init_vtkFilteringInstantiator();
  Init_vtkApplyFilterCommand();
  Init_vtkCellLocator();
  Init_vtkColorTransferFunction();
  Init_vtkCone();
  Init_vtkCylinder();
  Init_vtkDataObjectSource();
  Init_vtkDataSetSource();
  Init_vtkDataSetToDataSetFilter();
  Init_vtkHierarchicalBoxSource();
  Init_vtkHierarchicalBoxToHierarchicalBoxFilter();
  Init_vtkImageSource();
  Init_vtkImageToImageFilter();
  Init_vtkImageToStructuredPoints();
  Init_vtkImplicitBoolean();
  Init_vtkImplicitDataSet();
  Init_vtkImplicitSelectionLoop();
  Init_vtkImplicitSum();
  Init_vtkImplicitVolume();
  Init_vtkImplicitWindowFunction();
  Init_vtkMergePoints();
  Init_vtkMultiBlockApplyFilterCommand();
  Init_vtkPerlinNoise();
  Init_vtkPiecewiseFunction();
  Init_vtkPiecewiseFunctionSource();
  Init_vtkPiecewiseFunctionToPiecewiseFunctionFilter();
  Init_vtkPointSetSource();
  Init_vtkPointSetToPointSetFilter();
  Init_vtkPolyDataCollection();
  Init_vtkPolyDataSource();
  Init_vtkPolyDataToPolyDataFilter();
  Init_vtkRectilinearGridSource();
  Init_vtkRectilinearGridToPolyDataFilter();
  Init_vtkScalarTree();
  Init_vtkSimpleImageToImageFilter();
  Init_vtkSimpleScalarTree();
  Init_vtkSphere();
  Init_vtkSpline();
  Init_vtkStructuredGridSource();
  Init_vtkStructuredGridToPolyDataFilter();
  Init_vtkStructuredGridToStructuredGridFilter();
  Init_vtkStructuredPointsCollection();
  Init_vtkStructuredPointsSource();
  Init_vtkStructuredPointsToPolyDataFilter();
  Init_vtkStructuredPointsToStructuredPointsFilter();
  Init_vtkSuperquadric();
  Init_vtkUnstructuredGridSource();
  Init_vtkUnstructuredGridToPolyDataFilter();
  Init_vtkUnstructuredGridToUnstructuredGridFilter();
  Init_vtkCardinalSpline();
  Init_vtkCastToConcrete();
  Init_vtkDataSetToImageFilter();
  Init_vtkDataSetToPolyDataFilter();
  Init_vtkDataSetToStructuredGridFilter();
  Init_vtkDataSetToStructuredPointsFilter();
  Init_vtkDataSetToUnstructuredGridFilter();
  Init_vtkHierarchicalBoxToPolyDataFilter();
  Init_vtkImageInPlaceFilter();
  Init_vtkImageMultipleInputFilter();
  Init_vtkImageMultipleInputOutputFilter();
  Init_vtkImageTwoInputFilter();
  Init_vtkKochanekSpline();
  Init_vtkPiecewiseFunctionShiftScale();
  Init_vtkStructuredPointsToUnstructuredGridFilter();
}
